#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
from __future__ import print_function
from openeye import oechem


def CollectIncorrectStereo(mol):
    for atom in mol.GetAtoms():
        if atom.IsAromatic() and atom.HasStereoSpecified(oechem.OEAtomStereo_Tetrahedral):
            neighs = []
            for n in atom.GetAtoms():
                neighs.append(n.GetIdx())
            atom.SetData("incorrect_stereo_neighs", neighs)


def RemoveIncorrectStereo(mol):
    for atom in mol.GetAtoms():
        if atom.HasData("incorrect_stereo_neighs"):
            neighs = [mol.GetAtom(oechem.OEHasAtomIdx(a)) for a in atom.GetData("incorrect_stereo_neighs")]
            atom.SetStereo(neighs, oechem.OEAtomStereo_Tetrahedral, oechem.OEAtomStereo_Undefined)


mol = oechem.OEGraphMol()
oechem.OESmilesToMol(mol, "c1c[n@@H]cc1")
print(oechem.OEMolToSmiles(mol))

CollectIncorrectStereo(mol)
RemoveIncorrectStereo(mol)

print(oechem.OEMolToSmiles(mol))
# @ </SNIPPET>
